<?php
/**
 * A general (base) factory
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseFactory extends BaseFrameworkSystem {
	/**
	 * An instance of the real factory class
	 */
	private $realFactoryInstance = null;

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the real class (not BaseFactory)
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Setter for the *real* factory instance
	 *
	 * @param	$realFactoryInstance	An instance of the real factory class
	 * @return	void
	 */
	public final function setRealFactoryInstance (BaseFrameworkSystem $realFactoryInstance) {
		$this->realFactoryInstance = $realFactoryInstance;
	}

	/**
	 * Getter for the *real* factory instance
	 *
	 * @return	$realFactoryInstance	An instance of the real factory class
	 */
	protected final function getRealFactoryInstance () {
		return $this->realFactoryInstance;
	}
}

// [EOF]
?>
